==> scons_4.5.2+dfsg.orig.tar.xz: scons-4.5.2+dfsg/test/runtest/testargv.py <==
#!/usr/bin/env python
#
# __COPYRIGHT__
#
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
# KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
# WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
# WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#

__revision__ = "__FILE__ __REVISION__ __DATE__ __DEVELOPER__"

"""
Test subdir args for runtest.py, for example:

    python runtest.py test/subdir

"""

import os

import TestRuntest

test = TestRuntest.TestRuntest()
test.subdir('test', ['test', 'subdir'])

files = {}
files['pythonstring'] = TestRuntest.pythonstring
files['pythonflags'] = TestRuntest.pythonflags

files['one'] = os.path.join('test/subdir', 'test_one.py')
files['two'] = os.path.join('test/subdir', 'two.py')
files['three'] = os.path.join('test', 'test_three.py')

test.write_passing_test(files['one'])
test.write_passing_test(files['two'])
test.write_passing_test(files['three'])

expect_stdout = """\
%(pythonstring)s%(pythonflags)s %(one)s
PASSING TEST STDOUT
%(pythonstring)s%(pythonflags)s %(two)s
PASSING TEST STDOUT
""" % files

expect_stderr = """\
PASSING TEST STDERR
PASSING TEST STDERR
"""

test.run(arguments = '--no-progress test/subdir',
         status = 0,
         stdout = expect_stdout,
         stderr = expect_stderr)

test.pass_test()

# Local Variables:
# tab-width:4
# indent-tabs-mode:nil
# End:
# vim: set expandtab tabstop=4 shiftwidth=4:

==> scons_4.8.1+dfsg.orig.tar.xz: scons-4.8.1+dfsg/test/runtest/testargv.py <==
#!/usr/bin/env python
#
# MIT License
#
# Copyright The SCons Foundation
#
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
# KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
# WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
# WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

"""
Test subdir args for runtest.py, for example:

    python runtest.py test/subdir

"""

import os

import TestRuntest

test = TestRuntest.TestRuntest()
test.subdir('test', ['test', 'subdir'])

pythonstring = TestRuntest.pythonstring
pythonflags = TestRuntest.pythonflags

one = os.path.join('test', 'subdir', 'test_one.py')
two = os.path.join('test', 'subdir', 'two.py')
three = os.path.join('test', 'test_three.py')

test.write_passing_test(['test', 'subdir', 'test_one.py'])
test.write_passing_test(['test', 'subdir', 'two.py'])
test.write_passing_test(['test', 'test_three.py'])

expect_stdout = f"""\
{pythonstring}{pythonflags} {one}
PASSING TEST STDOUT
{pythonstring}{pythonflags} {two}
PASSING TEST STDOUT
"""

expect_stderr = """\
PASSING TEST STDERR
PASSING TEST STDERR
"""

test.run(
    arguments='--no-progress test/subdir',
    status=0,
    stdout=expect_stdout,
    stderr=expect_stderr,
)

test.pass_test()

# Local Variables:
# tab-width:4
# indent-tabs-mode:nil
# End:
# vim: set expandtab tabstop=4 shiftwidth=4:
